### Information for the Users
1.mig_crawl() -- this returns all the exchange rates.

2.mig_money(code, *kwargs) this returns the exchange rates according to your request code.

3.mig_console_tables() -- Returns the exchange rates information as a prettified table.

4.mig_help() this returns help information about this package